==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property styleControl This field is not currently supported and will not affect the output styling. Leave the default value.
 */
public data class
ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs(
    public val styleControl: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs> {
    override fun toJava():
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs.builder()
            .styleControl(styleControl.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgsBuilder
internal constructor() {
    private var styleControl: Output<String>? = null

    /**
     * @param value This field is not currently supported and will not affect the output styling. Leave the default value.
     */
    @JvmName("flxbitguspnpnsuw")
    public suspend fun styleControl(`value`: Output<String>) {
        this.styleControl = value
    }

    /**
     * @param value This field is not currently supported and will not affect the output styling. Leave the default value.
     */
    @JvmName("vvpqxprncxxlpplk")
    public suspend fun styleControl(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.styleControl = mapped
    }

    internal fun build():
        ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs =
        ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs(
            styleControl = styleControl ?: throw PulumiNullFieldException("styleControl"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property styleControl This field is not currently supported and will not affect the output styling. Leave the default value.
 */
public data class
ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs(
    public val styleControl: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs> {
    override fun toJava(): com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs.builder()
            .styleControl(styleControl.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgsBuilder
internal constructor() {
    private var styleControl: Output<String>? = null

    /**
     * @param value This field is not currently supported and will not affect the output styling. Leave the default value.
     */
    @JvmName("tirdqpmdqweveajt")
    public suspend fun styleControl(`value`: Output<String>) {
        this.styleControl = value
    }

    /**
     * @param value This field is not currently supported and will not affect the output styling. Leave the default value.
     */
    @JvmName("iadgypjalowvwljq")
    public suspend fun styleControl(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.styleControl = mapped
    }

    internal fun build(): ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs =
        ChannelEncoderSettingsCaptionDescriptionDestinationSettingsTtmlDestinationSettingsArgs(
            styleControl = styleControl ?: throw PulumiNullFieldException("styleControl"),
        )
}
